<?php

/**
 * @file
 *
 */

namespace Drupal\retina_images\Plugin\ImageEffect;

use Drupal\Core\Image\ImageInterface;
use Drupal\retina_images\RetinaFocalPointImageEffectBase;

/**
 * Class RetinaFocalPointScaleAndCropImageEffect
 * @package Drupal\retina_images\Plugin\ImageEffect
 */
class RetinaFocalPointScaleAndCropImageEffect extends RetinaFocalPointImageEffectBase {

  /**
   * {@inheritdoc}
   */
  public function applyEffect(ImageInterface $image) {
    $this->setOriginalImageSize($image->getWidth(), $image->getHeight());

    // First, attempt to resize the image.
    $originalDimensions = $this->getOriginalImageSize();
    $resize_data = self::calculateResizeData($originalDimensions['width'], $originalDimensions['height'], $this->multiplyDimension($this->configuration['width']), $this->multiplyDimension($this->configuration['height']));
    if (!$image->resize($resize_data['width'], $resize_data['height'])) {
      $this->logger->error(
        'Focal point scale and crop failed while resizing using the %toolkit toolkit on %path (%mimetype, %dimensions)',
        [
          '%toolkit' => $image->getToolkitId(),
          '%path' => $image->getSource(),
          '%mimetype' => $image->getMimeType(),
          '%dimensions' => $image->getWidth() . 'x' . $image->getHeight(),
        ]
      );
      return FALSE;
    }

    // Next, attempt to crop the image.
    return $this->applyCrop($image);
  }

}
