<?php

/**
 * @file
 *
 */

namespace Drupal\retina_images;

use Drupal\Core\Image\ImageInterface;
use Drupal\crop\Entity\Crop;
use Drupal\focal_point\FocalPointEffectBase;

/**
 * Class RetinaFocalPointScaleAndCropImageEffect
 * @package Drupal\retina_images\Plugin\ImageEffect
 */
abstract class RetinaFocalPointImageEffectBase extends FocalPointEffectBase {
  use RetinaImageEffectTrait;

  /**
   * {@inheritdoc}
   */
  public function applyCrop(ImageInterface $image) {
    $crop_type = $this->focalPointConfig->get('crop_type');

    /** @var \Drupal\crop\CropInterface $crop */
    if ($crop = Crop::findCrop($image->getSource(), $crop_type)) {
      // An existing crop has been found; set the size.
      $crop->setSize($this->multiplyDimension($this->configuration['width']), $this->multiplyDimension($this->configuration['height']));
    }
    else {
      // No existing crop could be found; create a new one using the size.
      $crop = $this->cropStorage->create([
        'type' => $crop_type,
        'x' => (int) round($image->getWidth() / 2),
        'y' => (int) round($image->getHeight() / 2),
        'width' => $this->multiplyDimension($this->configuration['width']),
        'height' => $this->multiplyDimension($this->configuration['height']),
      ]);
    }

    // Get the top-left anchor position of the crop area.
    $anchor = $this->getAnchor($image, $crop);

    if (!$image->crop($anchor['x'], $anchor['y'], $this->multiplyDimension($this->configuration['width']), $this->multiplyDimension($this->configuration['height']))) {
      $this->logger->error(
        'Focal point scale and crop failed while scaling and cropping using the %toolkit toolkit on %path (%mimetype, %dimensions, anchor: %anchor)',
        [
          '%toolkit' => $image->getToolkitId(),
          '%path' => $image->getSource(),
          '%mimetype' => $image->getMimeType(),
          '%dimensions' => $image->getWidth() . 'x' . $image->getHeight(),
          '%anchor' => $anchor,
        ]
      );
      return FALSE;
    }

    return TRUE;
  }
}
